import { OrganisationsEinheitenE2EComponent } from 'apps/admin-e2e/src/components/organisationseinheiten/organisationseinheiten.e2e.component';
import { ZustaendigeStelleDialogE2EComponent } from 'apps/admin-e2e/src/components/zustaendige-stelle/zustaendige-stelle-dialog.e2e.component';
import { AdminUserE2E } from 'apps/admin-e2e/src/model/util';
import { MainPage } from 'apps/admin-e2e/src/page-objects/main.po';
import { BenutzerE2EComponent } from '../../../components/benutzer/benutzer.e2e.component';
import { beChecked, exist, notBeChecked } from '../../../support/cypress.util';
import { loginAsAriane } from '../../../support/user-util';

describe('Organisationseinheit zu Benutzer hinzufügen', () => {
  const mainPage: MainPage = new MainPage();
  const benutzerPage: BenutzerE2EComponent = new BenutzerE2EComponent();
  const organisationsEinheitenComponent: OrganisationsEinheitenE2EComponent = new OrganisationsEinheitenE2EComponent();
  const zustaendigeStelleSearchComponent: ZustaendigeStelleDialogE2EComponent = new ZustaendigeStelleDialogE2EComponent();
  const organistationsEinheitOrdnungsamt: string = 'Ordnungsamt';
  const organisationsEinheitDenkmalpflege: string = 'Denkmalpflege';
  const organisationsEinheitWentorf: string = 'grundschule wentorf';
  const organisationsEinheitNone: string = 'keine zuständige Stelle zugewiesen';
  const vorname: string = 'Theo';
  const nachname: string = 'Testuser';
  const now1 = new Date();
  const benutzername1: string = 'testtheo' + now1.getSeconds().toString() + now1.getMilliseconds().toString();
  const emailAddress1: string = 'theo' + now1.getSeconds().toString() + now1.getMilliseconds().toString() + '@ozg-sh.de';
  const now2 = new Date(now1.getTime() + 1000);
  const benutzername2: string = 'testtheo' + now2.getSeconds().toString() + now2.getMilliseconds().toString();
  const emailAddress2: string = 'theo' + now2.getSeconds().toString() + now2.getMilliseconds().toString() + '@ozg-sh.de';

  const newUser1: AdminUserE2E = {
    vorname: vorname,
    nachname: nachname,
    benutzername: benutzername1,
    email: emailAddress1,
    isUser: true,
  };

  const newUser2: AdminUserE2E = {
    vorname: vorname,
    nachname: nachname,
    benutzername: benutzername2,
    email: emailAddress2,
    isUser: true,
    organisationseinheiten: ['Denkmalpflege'],
  };

  before(() => {
    loginAsAriane();
  });

  it('should click Hinzufügen button and show Organisationseinheiten in Benutzer page', () => {
    mainPage.benutzerNavigationItemIsVisible();
    mainPage.clickBenutzerNavigationItem();
    benutzerPage.hinzufuegenButtonIsVisible();

    benutzerPage.clickAddUser();
    exist(benutzerPage.getOrganisationsEinheitCheckbox(organisationsEinheitDenkmalpflege));
    exist(benutzerPage.getOrganisationsEinheitCheckbox(organistationsEinheitOrdnungsamt));
  });

  it('should add no Organisationseinheit to new user without selection and saving', () => {
    benutzerPage.addUser(newUser1);

    benutzerPage.stringExistsInUserEntry(organisationsEinheitNone, benutzername1);
  });

  it('should add Organisationseinheit to new user after selection and saving', () => {
    benutzerPage.clickAddUser();
    benutzerPage.addUser(newUser2);

    benutzerPage.stringExistsInUserEntry(organisationsEinheitDenkmalpflege, benutzername2);
  });

  it('should remove Organisationseinheit from existing user on deselection and save', () => {
    benutzerPage.clickUserEntry(benutzername2);
    beChecked(benutzerPage.getOrganisationsEinheitCheckbox(organisationsEinheitDenkmalpflege));

    benutzerPage.clickOrganisationsEinheitCheckbox(organisationsEinheitDenkmalpflege);
    benutzerPage.saveUser();

    benutzerPage.stringExistsInUserEntry(organisationsEinheitNone, benutzername2);
  });

  it('should add Organisationseinheit to existing user on selection and save', () => {
    benutzerPage.clickUserEntry(benutzername2);
    notBeChecked(benutzerPage.getOrganisationsEinheitCheckbox(organistationsEinheitOrdnungsamt));

    benutzerPage.clickOrganisationsEinheitCheckbox(organistationsEinheitOrdnungsamt);
    benutzerPage.saveUser();

    benutzerPage.stringExistsInUserEntry(organistationsEinheitOrdnungsamt, benutzername2);
  });

  it('should enable new Organisationseinheit for users after adding it', () => {
    mainPage.clickOrganisationsEinheitenNavigationItem();
    organisationsEinheitenComponent.clickHinzufuegen();
    zustaendigeStelleSearchComponent.enterSearchTerm(organisationsEinheitWentorf);
    zustaendigeStelleSearchComponent.getZustaendigeStelleTitle(0).then((title: string) => {
      zustaendigeStelleSearchComponent.clickFoundItem(0);
    });

    mainPage.clickBenutzerNavigationItem();
    benutzerPage.clickUserEntry(benutzername2);

    exist(benutzerPage.getOrganisationsEinheitCheckbox(organisationsEinheitWentorf));
  });

  it('should add new Organisationseinheit to existing user', () => {
    benutzerPage.clickOrganisationsEinheitCheckbox(organistationsEinheitOrdnungsamt);
    benutzerPage.saveUser();
    benutzerPage.stringExistsInUserEntry(organisationsEinheitWentorf, benutzername2);
  });
});
