import { AdminOrganisationsEinheit } from '@admin-client/organisations-einheit-shared';
import { mock, Mock } from '@alfa-client/test-utils';
import { TestBed } from '@angular/core/testing';
import KcAdminClient from '@keycloak/keycloak-admin-client';
import GroupRepresentation from '@keycloak/keycloak-admin-client/lib/defs/groupRepresentation';
import { createGroupRep } from '../../../organisations-einheit-shared/src/test/organisations-einheit';
import { AdminOrganisationsEinheitRepository } from './organisations-einheit.repository';

describe('AdminOrganisationsEinheitRepository', () => {
  let repository: AdminOrganisationsEinheitRepository;
  let kcAdminClient: Mock<KcAdminClient>;

  beforeEach(() => {
    kcAdminClient = mock(KcAdminClient);

    TestBed.configureTestingModule({
      providers: [{ provide: KcAdminClient, useValue: kcAdminClient }],
    });

    repository = TestBed.inject(AdminOrganisationsEinheitRepository);
  });

  describe('getList', () => {
    const groupRepArray: GroupRepresentation[] = Array.from({ length: 3 }, createGroupRep);

    beforeEach(() => {
      kcAdminClient.groups = <any>{
        find: jest.fn().mockReturnValue(Promise.resolve(groupRepArray)),
      };
    });

    it('should call kcAdminClient groups find', () => {
      repository.getList();
      expect(kcAdminClient.groups['find']).toHaveBeenCalled();
    });

    it('should return groups as organisationsEinheiten', (done) => {
      const groupRepNames: AdminOrganisationsEinheit[] = groupRepArray.map(
        (group: GroupRepresentation): AdminOrganisationsEinheit => ({
          name: group.name,
          id: group.id,
        }),
      );

      repository.getList().subscribe((result: AdminOrganisationsEinheit[]): void => {
        expect(result).toEqual(groupRepNames);
        done();
      });
    });

    it('should return empty array if no groups found', (done) => {
      (<any>kcAdminClient.groups).find = jest.fn().mockReturnValue(Promise.resolve(null));

      repository.getList().subscribe((result: AdminOrganisationsEinheit[]): void => {
        expect(result).toEqual([]);
        done();
      });
    });
  });

  describe('create', () => {
    const groupRep: GroupRepresentation = createGroupRep();
    const organisationsEinheit: AdminOrganisationsEinheit = {
      name: groupRep.name,
      id: groupRep.id,
    };

    beforeEach(() => {
      kcAdminClient.groups = <any>{
        create: jest.fn().mockReturnValue(Promise.resolve(groupRep)),
      };
    });

    it('should call kcAdminClient groups create', () => {
      repository.create(organisationsEinheit);
      expect(kcAdminClient.groups['create']).toHaveBeenCalled();
    });

    it('should return result as organisationseinheit', (done) => {
      repository.create(organisationsEinheit).subscribe((result: AdminOrganisationsEinheit): void => {
        expect(result).toEqual(organisationsEinheit);
        done();
      });
    });
  });
});
