import { AdminOrganisationsEinheit, AdminOrganisationsEinheitService } from '@admin-client/organisations-einheit-shared';
import { ApiRootLinkRel, ApiRootResource, ApiRootService } from '@alfa-client/api-root-shared';
import {
  isNotUndefined,
  mapToResource,
  ResourceRepository,
  ResourceSearchService,
  SearchResourceServiceConfig,
  StateResource,
  TechSharedModule,
} from '@alfa-client/tech-shared';
import { OzgcloudDialogService, UiModule } from '@alfa-client/ui';
import { ZustaendigeStelleModule } from '@alfa-client/zustaendige-stelle';
import {
  OrganisationsEinheitListResource,
  OrganisationsEinheitResource,
  OrganisationsEinheitService,
  ZUSTAENDIGE_STELLE_SERVICE,
  ZustaendigeStelleSharedModule,
} from '@alfa-client/zustaendige-stelle-shared';
import { CommonModule } from '@angular/common';
import { Component, inject, OnDestroy, OnInit, ViewContainerRef } from '@angular/core';
import { ButtonComponent } from '@ods/system';
import { filter, first, Observable } from 'rxjs';
import { SearchZustaendigeStelleDialogComponent } from '../../../../../zustaendige-stelle/src/lib/search-zustaendige-stelle-dialog/search-zustaendige-stelle-dialog.component';
import { OrganisationsEinheitListComponent } from './organisations-einheit-list/organisations-einheit-list.component';

@Component({
  selector: 'admin-organisations-einheit-container',
  templateUrl: './organisations-einheit-container.component.html',
  standalone: true,
  imports: [
    CommonModule,
    UiModule,
    ZustaendigeStelleModule,
    ZustaendigeStelleSharedModule,
    OrganisationsEinheitListComponent,
    TechSharedModule,
    ButtonComponent,
  ],
  providers: [
    {
      provide: ZUSTAENDIGE_STELLE_SERVICE,
      useFactory: createOrganisationEinheitService,
      deps: [ResourceRepository, ApiRootService],
    },
  ],
})
export class OrganisationsEinheitContainerComponent implements OnInit, OnDestroy {
  private readonly organisationsEinheitService = inject(AdminOrganisationsEinheitService);
  private readonly dialogService = inject(OzgcloudDialogService);
  private readonly viewContainerRef = inject(ViewContainerRef);

  organisationsEinheitenStateResource$: Observable<StateResource<AdminOrganisationsEinheit[]>>;
  createOrganisationsEinheitProgress$: Observable<StateResource<AdminOrganisationsEinheit>>;

  ngOnInit(): void {
    this.organisationsEinheitenStateResource$ = this.organisationsEinheitService.getAll();
  }

  ngOnDestroy(): void {
    this.organisationsEinheitService.refresh();
  }

  openDialog(): void {
    this.dialogService
      .openFullScreenDialog<SearchZustaendigeStelleDialogComponent<OrganisationsEinheitResource>>(
        SearchZustaendigeStelleDialogComponent,
        this.viewContainerRef,
        'Organisationseinheit auswählen',
      )
      .closed.pipe(first(), filter(isNotUndefined))
      .subscribe((organisationsEinheit: OrganisationsEinheitResource) => this.handleDialogResponse(organisationsEinheit));
  }

  handleDialogResponse(organisationsEinheit: OrganisationsEinheitResource): void {
    this.createOrganisationsEinheitProgress$ = this.organisationsEinheitService.create(
      this.mapToAdminOrganisationsEinheit(organisationsEinheit),
    );
  }

  mapToAdminOrganisationsEinheit(organisationsEinheitResource: OrganisationsEinheitResource): AdminOrganisationsEinheit {
    return {
      name: organisationsEinheitResource.name,
    };
  }
}

function createOrganisationEinheitService(
  resourceRepository: ResourceRepository,
  apiRootService: ApiRootService,
): OrganisationsEinheitService {
  return new OrganisationsEinheitService(createSearchService(resourceRepository, apiRootService));
}

function createSearchService(
  resourceRepository: ResourceRepository,
  apiRootService: ApiRootService,
): ResourceSearchService<ApiRootResource, OrganisationsEinheitListResource, OrganisationsEinheitResource> {
  return new ResourceSearchService<ApiRootResource, OrganisationsEinheitListResource, OrganisationsEinheitResource>(
    buildConfig(apiRootService),
    resourceRepository,
  );
}

function buildConfig(apiRootService: ApiRootService): SearchResourceServiceConfig<ApiRootResource> {
  return {
    baseResource: apiRootService.getApiRoot().pipe(mapToResource<ApiRootResource>()),
    searchLinkRel: ApiRootLinkRel.SEARCH_ORGANISATIONS_EINHEIT,
  };
}
