/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { AdminOrganisationsEinheit } from '@admin-client/organisations-einheit-shared';
import { existsAsHtmlElement, getElementFromFixture, mock } from '@alfa-client/test-utils';
import { CommonModule } from '@angular/common';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MatTooltipModule } from '@angular/material/tooltip';
import { ActivatedRoute } from '@angular/router';
import { ExclamationIconComponent, ListComponent, ListItemComponent } from '@ods/system';
import { getConvertedDataTestIdOf, getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent, MockModule } from 'ng-mocks';
import { createAdminOrganisationsEinheit } from '../../../../../organisations-einheit-shared/src/test/organisations-einheit';
import { OrganisationsEinheitListComponent } from './organisations-einheit-list.component';

describe('OrganisationsEinheitListComponent', () => {
  let component: OrganisationsEinheitListComponent;
  let fixture: ComponentFixture<OrganisationsEinheitListComponent>;

  const listSelector: string = getDataTestIdOf('organisations-einheit-list');
  const listItemSuffux: string = '-organisation-item';

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      providers: [
        {
          provide: ActivatedRoute,
          useValue: mock(ActivatedRoute),
        },
      ],
      imports: [
        CommonModule,
        OrganisationsEinheitListComponent,
        MockComponent(ListComponent),
        MockComponent(ListItemComponent),
        MockComponent(ExclamationIconComponent),
        MockModule(MatTooltipModule),
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(OrganisationsEinheitListComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    describe('organisationsEinheiten list', () => {
      describe('with organisationsEinheiten', () => {
        const organisationEinheit1: AdminOrganisationsEinheit = createAdminOrganisationsEinheit();
        const organisationEinheit2: AdminOrganisationsEinheit = createAdminOrganisationsEinheit();

        it('should show entries', () => {
          component.organisationsEinheitList = [organisationEinheit1, organisationEinheit2];

          fixture.detectChanges();

          existsAsHtmlElement(fixture, getConvertedDataTestIdOf(organisationEinheit1.name, listItemSuffux));
          existsAsHtmlElement(fixture, getConvertedDataTestIdOf(organisationEinheit2.name, listItemSuffux));
        });
      });

      describe('without organisationEinheiten', () => {
        it('should not have entries', () => {
          component.organisationsEinheitList = [createAdminOrganisationsEinheit()];

          fixture.detectChanges();

          expect(getElementFromFixture(fixture, listSelector).hasChildNodes()).toBeTruthy();
        });
      });
    });
  });
});
