import { ROUTES } from '@admin-client/shared';
import { NavigationService } from '@alfa-client/navigation-shared';
import { existsAsHtmlElement, getElementComponentFromFixtureByCss, mock, Mock, triggerEvent } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { FormBuilder } from '@angular/forms';
import { TextInputComponent } from '@ods/system';
import { getDataTestIdAttributeOf, getDataTestIdOf } from '../../../../../tech-shared/test/data-test';
import { AdminStatistikFieldsFormComponent } from './admin-statistik-fields-form.component';
import { StatistikFieldsFormService } from './statistik-fields.formservice';

describe('AdminStatistikFieldsFormComponent', () => {
  let component: AdminStatistikFieldsFormComponent;
  let fixture: ComponentFixture<AdminStatistikFieldsFormComponent>;

  const formEngineInputTestId: string = getDataTestIdOf('form-engine-input');
  const formIdInputTestId: string = getDataTestIdOf('form-id-input');
  const addDataFieldButtonTestId: string = getDataTestIdAttributeOf('add-data-field-button');
  const saveButtonTestId: string = getDataTestIdAttributeOf('save-statistik-fields-button');
  const cancelButtonTestId: string = getDataTestIdAttributeOf('cancel-statistik-fields-button');
  const dataField1TestId: string = getDataTestIdOf('data-statistik-field-0');

  let formService: StatistikFieldsFormService;
  let navigationService: Mock<NavigationService>;

  beforeEach(() => {
    formService = new StatistikFieldsFormService(new FormBuilder());
    navigationService = mock(NavigationService);
  });

  beforeEach(async () => {
    TestBed.overrideComponent(AdminStatistikFieldsFormComponent, {
      set: {
        providers: [
          {
            provide: StatistikFieldsFormService,
            useValue: formService,
          },
          {
            provide: NavigationService,
            useValue: navigationService,
          },
        ],
      },
    });

    await TestBed.configureTestingModule({
      imports: [AdminStatistikFieldsFormComponent],
      providers: [{ provide: StatistikFieldsFormService, useValue: formService }],
    }).compileComponents();

    fixture = TestBed.createComponent(AdminStatistikFieldsFormComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  describe('component', () => {
    it('should create', () => {
      expect(component).toBeTruthy();
    });

    it('should set form controls', () => {
      expect(component.formEngineFormControl).toBeDefined();
      expect(component.formIdFormControl).toBeDefined();
      expect(component.dataFieldsFormControls).toBeDefined();
    });

    describe('addDataField', () => {
      it('should call form service', () => {
        formService.addDataField = jest.fn();

        component.addDataField();

        expect(formService.addDataField).toHaveBeenCalled();
      });
    });

    describe('onCancel', () => {
      it('should call navigation service', () => {
        component.onCancel();

        expect(navigationService.navigate).toHaveBeenCalledWith(ROUTES.STATISTIK);
      });
    });
  });

  describe('template', () => {
    describe('form engine input', () => {
      it('should exists', () => {
        fixture.detectChanges();

        existsAsHtmlElement(fixture, formEngineInputTestId);
      });

      it('should have been called with inputs', () => {
        fixture.detectChanges();

        const formEngineInput: TextInputComponent = getElementComponentFromFixtureByCss<TextInputComponent>(
          fixture,
          formEngineInputTestId,
        );

        expect(formEngineInput.fieldControl).toEqual(component.formEngineFormControl);
      });
    });

    describe('form id input', () => {
      it('should exists', () => {
        fixture.detectChanges();

        existsAsHtmlElement(fixture, formIdInputTestId);
      });

      it('should have been called with inputs', () => {
        fixture.detectChanges();

        const formIdInput: TextInputComponent = getElementComponentFromFixtureByCss<TextInputComponent>(
          fixture,
          formIdInputTestId,
        );

        expect(formIdInput.fieldControl).toEqual(component.formIdFormControl);
      });
    });

    describe('data field input', () => {
      it('should exists', () => {
        fixture.detectChanges();

        existsAsHtmlElement(fixture, dataField1TestId);
      });

      it('should have been called with inputs', () => {
        fixture.detectChanges();

        const dataFieldInput: TextInputComponent = getElementComponentFromFixtureByCss<TextInputComponent>(
          fixture,
          dataField1TestId,
        );

        expect(dataFieldInput.fieldControl).toEqual(component.dataFieldsFormControls[0]);
      });
    });

    describe('add data field button', () => {
      it('should exists', () => {
        fixture.detectChanges();

        existsAsHtmlElement(fixture, addDataFieldButtonTestId);
      });

      describe('output', () => {
        describe('clickEmitter', () => {
          it('should call handler', () => {
            fixture.detectChanges();
            component.addDataField = jest.fn();

            triggerEvent({
              fixture,
              elementSelector: addDataFieldButtonTestId,
              name: 'clickEmitter',
            });

            expect(component.addDataField).toHaveBeenCalled();
          });
        });
      });
    });

    describe('save button', () => {
      it('should exists', () => {
        fixture.detectChanges();

        existsAsHtmlElement(fixture, saveButtonTestId);
      });
    });

    describe('cancel button', () => {
      it('should exists', () => {
        fixture.detectChanges();

        existsAsHtmlElement(fixture, cancelButtonTestId);
      });

      describe('output', () => {
        describe('clickEmitter', () => {
          it('should call handler', () => {
            component.onCancel = jest.fn();
            fixture.detectChanges();

            triggerEvent({
              fixture,
              elementSelector: cancelButtonTestId,
              name: 'clickEmitter',
            });

            expect(component.onCancel).toHaveBeenCalled();
          });
        });
      });
    });
  });
});
