/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { createCommandErrorStateResource, createCommandResource } from 'libs/command-shared/test/command';
import { createApiError } from 'libs/tech-shared/test/error';
import { ButtonWithSpinnerComponent } from './button-with-spinner.component';

import * as ResourceUtils from 'libs/tech-shared/src/lib/resource/resource.util';

describe('ButtonWithSpinnerComponent', () => {
  let component: ButtonWithSpinnerComponent;
  let fixture: ComponentFixture<ButtonWithSpinnerComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [ButtonWithSpinnerComponent],
    }).compileComponents();

    fixture = TestBed.createComponent(ButtonWithSpinnerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('onInit', () => {
    it('should call getStateResource', () => {
      component.getStateResource = jest.fn();

      component.ngOnInit();

      expect(component.getStateResource).toHaveBeenCalled();
    });
  });

  describe('getStateResource', () => {
    it('should return stateResource', () => {
      component.stateResource = ResourceUtils.createStateResource(createCommandResource());

      component.getStateResource();

      const valid: boolean = ResourceUtils.isValidStateResource(component.stateResource);
      expect(valid).toBeTruthy();
    });

    it('should return empty stateResource', () => {
      const spy = jest.spyOn(ResourceUtils, 'createEmptyStateResource');
      component.stateResource = null;

      component.getStateResource();

      expect(spy).toHaveBeenCalled();
    });
  });

  describe('isLoading', () => {
    it('should return false', () => {
      component.stateResource.loading = component.stateResource.reload = false;

      const isLoading: boolean = component.isLoading;

      expect(isLoading).toBeFalsy();
    });

    it('should return true if stateResource is loading', () => {
      component.stateResource.loading = true;
      component.stateResource.reload = false;

      const isLoading: boolean = component.isLoading;

      expect(isLoading).toBeTruthy();
    });

    it('should return true if stateResource is reloading', () => {
      component.stateResource.loading = false;
      component.stateResource.reload = true;

      const isLoading: boolean = component.isLoading;

      expect(isLoading).toBeTruthy();
    });
  });

  describe('isError', () => {
    it('should return false if error is not set', () => {
      component.stateResource.error = null;

      const isError: boolean = component.isError;

      expect(isError).toBeFalsy();
    });

    it('should return false if error is set and error is ApiError', () => {
      component.stateResource.error = createApiError();

      const isError: boolean = component.isError;

      expect(isError).toBeFalsy();
    });

    it('should return true if error is set and error is not ApiError', () => {
      component.stateResource = createCommandErrorStateResource();

      const isError: boolean = component.isError;

      expect(isError).toBeTruthy();
    });
  });
});
