/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { existsAsHtmlElement, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ButtonWithSpinnerComponent } from '@ods/component';
import { DeleteVorgangFinallyIconComponent } from '@ods/system';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { EndgueltigLoeschenButtonComponent } from './endgueltig-loeschen-button.component';

describe('EndgueltigLoeschenButtonComponent', () => {
  let component: EndgueltigLoeschenButtonComponent;
  let fixture: ComponentFixture<EndgueltigLoeschenButtonComponent>;

  const endgueltigLoeschenButton = getDataTestIdOf('endgueltig-loeschen-button');
  const endgueltigLoeschenIconButton = getDataTestIdOf('endgueltig-loeschen-icon-button');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        EndgueltigLoeschenButtonComponent,
        MockComponent(ButtonWithSpinnerComponent),
        MockComponent(DeleteVorgangFinallyIconComponent),
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(EndgueltigLoeschenButtonComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('button with spinner', () => {
    it('should be hidden', () => {
      component.showAsIconButton = true;

      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, endgueltigLoeschenButton);
    });

    it('should be visible', () => {
      component.showAsIconButton = false;

      fixture.detectChanges();

      existsAsHtmlElement(fixture, endgueltigLoeschenButton);
    });
  });

  describe('icon button with spinner', () => {
    it('should be hidden', () => {
      component.showAsIconButton = false;

      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, endgueltigLoeschenIconButton);
    });

    it('should be visible', () => {
      component.showAsIconButton = true;

      fixture.detectChanges();

      existsAsHtmlElement(fixture, endgueltigLoeschenIconButton);
    });
  });
});
