/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { existsAsHtmlElement, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ButtonWithSpinnerComponent } from '@ods/component';
import { UndoRequestVorgangDeletionIconComponent } from '@ods/system';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { LoeschAnforderungZuruecknehmenButtonComponent } from './loesch-anforderung-zuruecknehmen-button.component';

describe('LoeschAnforderungZuruecknehmenButtonComponent', () => {
  let component: LoeschAnforderungZuruecknehmenButtonComponent;
  let fixture: ComponentFixture<LoeschAnforderungZuruecknehmenButtonComponent>;

  const loeschenAnfordernZuruecknehmenButton: string = getDataTestIdOf('loesch-anforderung-zuruecknehmen-button');
  const loeschenAnfordernZuruecknehmenIconButton: string = getDataTestIdOf('loesch-anforderung-zuruecknehmen-icon-button');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        LoeschAnforderungZuruecknehmenButtonComponent,
        MockComponent(ButtonWithSpinnerComponent),
        MockComponent(UndoRequestVorgangDeletionIconComponent),
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(LoeschAnforderungZuruecknehmenButtonComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('show as icon button', () => {
    beforeEach(() => {
      component.showAsIconButton = true;
      fixture.detectChanges();
    });

    it('should hide button', () => {
      notExistsAsHtmlElement(fixture, loeschenAnfordernZuruecknehmenButton);
    });

    it('should show iconButton', () => {
      existsAsHtmlElement(fixture, loeschenAnfordernZuruecknehmenIconButton);
    });
  });

  describe('show as button', () => {
    beforeEach(() => {
      component.showAsIconButton = false;
      fixture.detectChanges();
    });

    it('should show button', () => {
      existsAsHtmlElement(fixture, loeschenAnfordernZuruecknehmenButton);
    });

    it('should hide iconButton visible', () => {
      notExistsAsHtmlElement(fixture, loeschenAnfordernZuruecknehmenIconButton);
    });
  });
});
