/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { HasLinkPipe, createStateResource } from '@alfa-client/tech-shared';
import { mock } from '@alfa-client/test-utils';
import { VorgangCommandService, VorgangWithEingangLinkRel } from '@alfa-client/vorgang-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ButtonWithSpinnerComponent } from '@ods/component';
import { EditIconComponent } from '@ods/system';
import { createCommandResource } from 'libs/command-shared/test/command';
import { getDataTestIdAttributeOf } from 'libs/tech-shared/test/data-test';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { BearbeitenButtonComponent } from './bearbeiten-button.component';

describe('BearbeitenButtonComponent', () => {
  let component: BearbeitenButtonComponent;
  let fixture: ComponentFixture<BearbeitenButtonComponent>;

  const bearbeitenButton: string = getDataTestIdAttributeOf('bearbeiten-button');
  const bearbeitenIconButton: string = getDataTestIdAttributeOf('bearbeiten-icon-button');

  const vorgangCommandService = {
    ...mock(VorgangCommandService),
    getCommandStateResources: () => of(createStateResource(createCommandResource())),
  };

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        BearbeitenButtonComponent,
        MockComponent(ButtonWithSpinnerComponent),
        MockComponent(EditIconComponent),
        HasLinkPipe,
      ],
      providers: [
        {
          provide: VorgangCommandService,
          useValue: vorgangCommandService,
        },
      ],
    });
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(BearbeitenButtonComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('bearbeiten', () => {
    it('should call vorgang service', () => {
      component.bearbeiten();

      expect(vorgangCommandService.bearbeiten).toHaveBeenCalled();
    });
  });

  describe('bearbeiten button', () => {
    beforeEach(() => {
      component.showAsIconButton = false;
      fixture.detectChanges();
    });

    it('should be hidden', () => {
      component.vorgang = createVorgangWithEingangResource();

      fixture.detectChanges();
      const buttonElement = fixture.nativeElement.querySelector(bearbeitenButton);

      expect(buttonElement).not.toBeInstanceOf(HTMLElement);
    });

    it('should be visible', () => {
      component.vorgang = createVorgangWithEingangResource([VorgangWithEingangLinkRel.BEARBEITEN]);

      fixture.detectChanges();
      const buttonElement = fixture.nativeElement.querySelector(bearbeitenButton);

      expect(buttonElement).toBeInstanceOf(HTMLElement);
    });
  });

  describe('bearbeiten icon button', () => {
    beforeEach(() => {
      component.showAsIconButton = true;
      fixture.detectChanges();
    });

    it('should be hidden', () => {
      component.vorgang = createVorgangWithEingangResource();

      fixture.detectChanges();
      const buttonElement = fixture.nativeElement.querySelector(bearbeitenIconButton);

      expect(buttonElement).not.toBeInstanceOf(HTMLElement);
    });

    it('should be visible', () => {
      component.vorgang = createVorgangWithEingangResource([VorgangWithEingangLinkRel.BEARBEITEN]);

      fixture.detectChanges();
      const buttonElement = fixture.nativeElement.querySelector(bearbeitenIconButton);

      expect(buttonElement).toBeInstanceOf(HTMLElement);
    });
  });
});
