/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { HasLinkPipe, createStateResource } from '@alfa-client/tech-shared';
import { mock } from '@alfa-client/test-utils';
import { VorgangCommandService, VorgangWithEingangLinkRel } from '@alfa-client/vorgang-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ButtonWithSpinnerComponent } from '@ods/component';
import { UndoIconComponent } from '@ods/system';
import { createCommandResource } from 'libs/command-shared/test/command';
import { getDataTestIdAttributeOf } from 'libs/tech-shared/test/data-test';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { WiedereroeffnenButtonComponent } from './wiedereroeffnen-button.component';

describe('WiedereroeffnenButtonComponent', () => {
  let component: WiedereroeffnenButtonComponent;
  let fixture: ComponentFixture<WiedereroeffnenButtonComponent>;
  const wiedereroeffnenButton: string = getDataTestIdAttributeOf('wiedereroeffnen-button');
  const wiedereroeffnenIconButton: string = getDataTestIdAttributeOf('wiedereroeffnen-icon-button');

  const vorgangCommandService = {
    ...mock(VorgangCommandService),
    getCommandStateResources: () => of(createStateResource(createCommandResource())),
  };

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        WiedereroeffnenButtonComponent,
        HasLinkPipe,
        MockComponent(ButtonWithSpinnerComponent),
        MockComponent(UndoIconComponent),
      ],
      providers: [
        {
          provide: VorgangCommandService,
          useValue: vorgangCommandService,
        },
      ],
    });
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(WiedereroeffnenButtonComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    it('should call service', () => {
      component.ngOnInit();

      expect(vorgangCommandService.getWiedereroeffnenCommand).toHaveBeenCalled();
    });
  });

  describe('wiedereroeffnen', () => {
    it('should call vorgang service', () => {
      component.wiedereroeffnen();

      expect(vorgangCommandService.wiedereroeffnen).toHaveBeenCalled();
    });
  });

  describe('wiedereroeffnen button', () => {
    beforeEach(() => {
      component.showAsIconButton = false;
      fixture.detectChanges();
    });

    it('should be hidden', () => {
      component.vorgang = createVorgangWithEingangResource();

      fixture.detectChanges();
      const buttonElement = fixture.nativeElement.querySelector(wiedereroeffnenButton);

      expect(buttonElement).not.toBeInstanceOf(HTMLElement);
    });

    it('should be visible', () => {
      component.vorgang = createVorgangWithEingangResource([VorgangWithEingangLinkRel.WIEDEREROEFFNEN]);

      fixture.detectChanges();
      const buttonElement = fixture.nativeElement.querySelector(wiedereroeffnenButton);

      expect(buttonElement).toBeInstanceOf(HTMLElement);
    });
  });

  describe('wiedereroeffnen icon button', () => {
    beforeEach(() => {
      component.showAsIconButton = true;
      fixture.detectChanges();
    });

    it('should be hidden', () => {
      component.vorgang = createVorgangWithEingangResource();

      fixture.detectChanges();
      const buttonElement = fixture.nativeElement.querySelector(wiedereroeffnenIconButton);

      expect(buttonElement).not.toBeInstanceOf(HTMLElement);
    });

    it('should be visible', () => {
      component.vorgang = createVorgangWithEingangResource([VorgangWithEingangLinkRel.WIEDEREROEFFNEN]);

      fixture.detectChanges();
      const buttonElement = fixture.nativeElement.querySelector(wiedereroeffnenIconButton);

      expect(buttonElement).toBeInstanceOf(HTMLElement);
    });
  });
});
