/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidModule } from '@alfa-client/bescheid';
import { BinaryFileModule } from '@alfa-client/binary-file';
import { CollaborationModule } from '@alfa-client/collaboration';
import { ForwardByOzgcloudButtonContainerComponent, ForwardingModule } from '@alfa-client/forwarding';
import { HistorieModule } from '@alfa-client/historie';
import { KommentarModule } from '@alfa-client/kommentar';
import { LoeschAnforderungModule } from '@alfa-client/loesch-anforderung';
import { LoeschAnforderungSharedModule } from '@alfa-client/loesch-anforderung-shared';
import { PostfachModule } from '@alfa-client/postfach';
import { PostfachSharedModule } from '@alfa-client/postfach-shared';
import { TechSharedModule } from '@alfa-client/tech-shared';
import { UiModule } from '@alfa-client/ui';
import { UserProfileModule } from '@alfa-client/user-profile';
import { UserProfileSharedModule } from '@alfa-client/user-profile-shared';
import { VorgangSharedModule } from '@alfa-client/vorgang-shared';
import { VorgangSharedUiModule } from '@alfa-client/vorgang-shared-ui';
import { WiedervorlageModule } from '@alfa-client/wiedervorlage';
import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import {
  ButtonWithSpinnerComponent,
  FileUploadEditorComponent,
  SingleFileUploadEditorComponent,
  TextEditorComponent,
  TextareaEditorComponent,
} from '@ods/component';
import {
  ArchiveIconComponent,
  AttachmentComponent,
  AttachmentWrapperComponent,
  BescheidGenerateIconComponent,
  BescheidStatusTextComponent,
  BescheidUploadIconComponent,
  ButtonCardComponent,
  ButtonComponent,
  CheckCircleIconComponent,
  CheckIconComponent,
  CloseIconComponent,
  DiscardVorgangIconComponent,
  DropdownMenuComponent,
  DropdownMenuTextItemComponent,
  EditIconComponent,
  ErrorMessageComponent,
  ExclamationIconComponent,
  FileIconComponent,
  MoreIconComponent,
  RadioButtonCardComponent,
  SaveIconComponent,
  SendIconComponent,
  SpinnerIconComponent,
  StampIconComponent,
  TooltipDirective,
  UndoIconComponent,
} from '@ods/system';
import { AktenzeichenEditDialogComponent } from './aktenzeichen-edit-dialog/aktenzeichen-edit-dialog.component';
import { AktenzeichenEditableComponent } from './aktenzeichen-editable/aktenzeichen-editable.component';
import { AbschliessenButtonComponent } from './buttons/abschliessen-button/abschliessen-button.component';
import { AnnehmenButtonComponent } from './buttons/annehmen-button/annehmen-button.component';
import { BearbeitenButtonComponent } from './buttons/bearbeiten-button/bearbeiten-button.component';
import { BescheidenButtonComponent } from './buttons/bescheiden-button/bescheiden-button.component';
import { VerwerfenButtonComponent } from './buttons/verwerfen-button/verwerfen-button.component';
import { WiedereroeffnenButtonComponent } from './buttons/wiedereroeffnen-button/wiedereroeffnen-button.component';
import { ZurueckholenButtonComponent } from './buttons/zurueckholen-button/zurueckholen-button.component';
import { ZurueckstellenButtonComponent } from './buttons/zurueckstellen-button/zurueckstellen-button.component';
import { VorgangDetailActionButtonsComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-action-buttons/vorgang-detail-action-buttons.component';
import { VorgangDetailAntragstellerComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-antragsteller/vorgang-detail-antragsteller.component';
import { VorgangDetailAreaComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-area.component';
import { VorgangDetailFormularButtonsComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-formular-buttons/vorgang-detail-formular-buttons.component';
import { VorgangDetailAntragDataComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-formular-daten/vorgang-detail-antrag-data/vorgang-detail-antrag-data.component';
import { VorgangDetailEingangHeaderComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-formular-daten/vorgang-detail-antrag-data/vorgang-detail-eingang-header/vorgang-detail-eingang-header.component';
import { VorgangDetailDateienContainerComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-formular-daten/vorgang-detail-dateien-container/vorgang-detail-dateien-container.component';
import { VorgangDetailFormDataTableComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-formular-daten/vorgang-detail-form-data-table/vorgang-detail-form-data-table.component';
import { VorgangDetailFormularDatenComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-formular-daten/vorgang-detail-formular-daten.component';
import { VorgangDetailHeaderComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-header/vorgang-detail-header.component';
import { VorgangDetailBackButtonContainerComponent } from './vorgang-detail-page/vorgang-detail-back-button-container/vorgang-detail-back-button-container.component';
import { VorgangDetailBackButtonComponent } from './vorgang-detail-page/vorgang-detail-back-button-container/vorgang-detail-back-button/vorgang-detail-back-button.component';
import { VorgangDetailBescheidenResultAttachmentsComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-result/vorgang-detail-bescheiden-result-attachments/vorgang-detail-bescheiden-result-attachments.component';
import { VorgangDetailBescheidenResultDokumentComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-result/vorgang-detail-bescheiden-result-dokument/vorgang-detail-bescheiden-result-dokument.component';
import { VorgangDetailBescheidenResultNachrichtComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-result/vorgang-detail-bescheiden-result-nachricht/vorgang-detail-bescheiden-result-nachricht.component';
import { VorgangDetailBescheidenResultStatusComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-result/vorgang-detail-bescheiden-result-status/vorgang-detail-bescheiden-result-status.component';
import { VorgangDetailBescheidenResultComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-result/vorgang-detail-bescheiden-result.component';
import { VorgangDetailBescheidenStepButtonComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-step-buttons/vorgang-detail-bescheiden-step-button/vorgang-detail-bescheiden-step-button.component';
import { VorgangDetailBescheidenStepButtonsComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-step-buttons/vorgang-detail-bescheiden-step-buttons.component';
import { VorgangDetailBescheidenStepTitleComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-step-title/vorgang-detail-bescheiden-step-title.component';
import { VorgangDetailBescheidenAbbrechenButtonComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps-content/vorgang-detail-bescheiden-abbrechen-button/vorgang-detail-bescheiden-abbrechen-button.component';
import { VorgangDetailBescheidenAbbrechenDialogComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps-content/vorgang-detail-bescheiden-abbrechen-dialog/vorgang-detail-bescheiden-abbrechen-dialog.component';
import { VorgangDetailBescheidenAntragBescheidenComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps-content/vorgang-detail-bescheiden-antrag-bescheiden/vorgang-detail-bescheiden-antrag-bescheiden.component';
import { VorgangDetailBescheidenBescheidVersendenComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps-content/vorgang-detail-bescheiden-bescheid-versenden/vorgang-detail-bescheiden-bescheid-versenden.component';
import { VorgangDetailBescheidenAttachmentHochladenComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps-content/vorgang-detail-bescheiden-dokumente-hinzufuegen/vorgang-detail-bescheiden-attachment-hochladen/vorgang-detail-bescheiden-attachment-hochladen.component';
import { VorgangDetailBescheidenBescheidAutomatischErstellenComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps-content/vorgang-detail-bescheiden-dokumente-hinzufuegen/vorgang-detail-bescheiden-bescheid-automatisch-erstellen/vorgang-detail-bescheiden-bescheid-automatisch-erstellen.component';
import { VorgangDetailBescheidenDokumentHochladenComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps-content/vorgang-detail-bescheiden-dokumente-hinzufuegen/vorgang-detail-bescheiden-dokument-hochladen/vorgang-detail-bescheiden-dokument-hochladen.component';
import { VorgangDetailBescheidenDokumenteHinzufuegenComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps-content/vorgang-detail-bescheiden-dokumente-hinzufuegen/vorgang-detail-bescheiden-dokumente-hinzufuegen.component';
import { VorgangDetailBescheidenStepContentComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps-content/vorgang-detail-bescheiden-step-content/vorgang-detail-bescheiden-step-content.component';
import { VorgangDetailBescheidenStepsContentComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps-content/vorgang-detail-bescheiden-steps-content.component';
import { VorgangDetailBescheidenUeberspringenButtonComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps-content/vorgang-detail-bescheiden-ueberspringen-button/vorgang-detail-bescheiden-ueberspringen-button.component';
import { VorgangDetailBescheidenUeberspringenDialogComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps-content/vorgang-detail-bescheiden-ueberspringen-dialog/vorgang-detail-bescheiden-ueberspringen-dialog.component';
import { VorgangDetailBescheidenStepsComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps.component';
import { VorgangDetailBescheidenWeiterButtonComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-weiter-button/vorgang-detail-bescheiden-weiter-button.component';
import { VorgangDetailBescheidenComponent } from './vorgang-detail-page/vorgang-detail-bescheiden/vorgang-detail-bescheiden.component';
import { VorgangArchiveConfirmationDialogContainerComponent } from './vorgang-detail-page/vorgang-detail-more-menu/vorgang-archive-container/vorgang-archive-confirmation-dialog-container/vorgang-archive-confirmation-dialog-container.component';
import { VorgangArchiveConfirmationDialogComponent } from './vorgang-detail-page/vorgang-detail-more-menu/vorgang-archive-container/vorgang-archive-confirmation-dialog-container/vorgang-archive-confirmation-dialog/vorgang-archive-confirmation-dialog.component';
import { VorgangArchiveContainerComponent } from './vorgang-detail-page/vorgang-detail-more-menu/vorgang-archive-container/vorgang-archive-container.component';
import { VorgangDetailMoreMenuComponent } from './vorgang-detail-page/vorgang-detail-more-menu/vorgang-detail-more-menu.component';
import { VorgangExportContainerComponent } from './vorgang-detail-page/vorgang-detail-more-menu/vorgang-export-container/vorgang-export-container.component';
import { ProcessVorgangContainerComponent } from './vorgang-detail-page/vorgang-detail-more-menu/vorgang-process-vorgang-container/vorgang-process-vorgang-container.component';
import { VorgangDetailPageComponent } from './vorgang-detail-page/vorgang-detail-page.component';

const routes: Routes = [
  {
    path: '',
    component: VorgangDetailPageComponent,
  },
];

@NgModule({
  imports: [
    CommonModule,
    RouterModule.forChild(routes),
    VorgangSharedModule,
    UiModule,
    TechSharedModule,
    WiedervorlageModule,
    BinaryFileModule,
    ForwardingModule,
    KommentarModule,
    VorgangSharedUiModule,
    UserProfileModule,
    UserProfileSharedModule,
    PostfachSharedModule,
    PostfachModule,
    HistorieModule,
    LoeschAnforderungModule,
    LoeschAnforderungSharedModule,
    BescheidModule,
    RadioButtonCardComponent,
    ButtonComponent,
    ButtonCardComponent,
    UndoIconComponent,
    CloseIconComponent,
    EditIconComponent,
    ExclamationIconComponent,
    SaveIconComponent,
    SendIconComponent,
    StampIconComponent,
    SpinnerIconComponent,
    BescheidUploadIconComponent,
    BescheidGenerateIconComponent,
    AttachmentComponent,
    AttachmentWrapperComponent,
    ButtonWithSpinnerComponent,
    FileUploadEditorComponent,
    SingleFileUploadEditorComponent,
    TextEditorComponent,
    TextareaEditorComponent,
    BescheidStatusTextComponent,
    ErrorMessageComponent,
    CollaborationModule,
    ArchiveIconComponent,
    CheckCircleIconComponent,
    CheckIconComponent,
    DropdownMenuComponent,
    DropdownMenuTextItemComponent,
    MoreIconComponent,
    FileIconComponent,
    ForwardByOzgcloudButtonContainerComponent,
    TooltipDirective,
    EditIconComponent,
    DiscardVorgangIconComponent,
  ],
  declarations: [
    VorgangDetailPageComponent,
    VorgangDetailAreaComponent,
    VorgangDetailHeaderComponent,
    VorgangDetailEingangHeaderComponent,
    VorgangDetailFormDataTableComponent,
    VorgangDetailActionButtonsComponent,
    VorgangDetailFormularButtonsComponent,
    AnnehmenButtonComponent,
    BearbeitenButtonComponent,
    VerwerfenButtonComponent,
    ZurueckholenButtonComponent,
    BescheidenButtonComponent,
    AbschliessenButtonComponent,
    ZurueckstellenButtonComponent,
    WiedereroeffnenButtonComponent,
    VorgangDetailAntragstellerComponent,
    VorgangDetailBackButtonComponent,
    VorgangDetailBackButtonContainerComponent,
    VorgangDetailFormularDatenComponent,
    VorgangDetailAntragDataComponent,
    VorgangDetailMoreMenuComponent,
    VorgangExportContainerComponent,
    ProcessVorgangContainerComponent,
    AktenzeichenEditableComponent,
    AktenzeichenEditDialogComponent,
    VorgangDetailBescheidenComponent,
    VorgangDetailBescheidenResultComponent,
    VorgangDetailBescheidenStepButtonComponent,
    VorgangDetailBescheidenStepsComponent,
    VorgangDetailBescheidenStepButtonsComponent,
    VorgangDetailBescheidenWeiterButtonComponent,
    VorgangDetailBescheidenStepTitleComponent,
    VorgangDetailBescheidenStepsContentComponent,
    VorgangDetailBescheidenStepContentComponent,
    VorgangDetailBescheidenResultStatusComponent,
    VorgangDetailBescheidenUeberspringenButtonComponent,
    VorgangDetailBescheidenUeberspringenDialogComponent,
    VorgangDetailBescheidenAbbrechenDialogComponent,
    VorgangDetailBescheidenAbbrechenButtonComponent,
    VorgangDetailBescheidenDokumentHochladenComponent,
    VorgangDetailBescheidenBescheidAutomatischErstellenComponent,
    VorgangDetailBescheidenDokumenteHinzufuegenComponent,
    VorgangDetailBescheidenAntragBescheidenComponent,
    VorgangDetailBescheidenAttachmentHochladenComponent,
    VorgangDetailBescheidenResultDokumentComponent,
    VorgangDetailBescheidenResultAttachmentsComponent,
    VorgangDetailBescheidenBescheidVersendenComponent,
    VorgangDetailBescheidenResultNachrichtComponent,
    VorgangDetailDateienContainerComponent,
    VorgangArchiveContainerComponent,
    VorgangArchiveConfirmationDialogContainerComponent,
    VorgangArchiveConfirmationDialogComponent,
  ],
  exports: [VorgangDetailAntragstellerComponent, VorgangDetailAntragDataComponent, VorgangDetailBescheidenComponent],
})
export class VorgangDetailModule {}
